<!--
 SPDX-FileCopyrightText: Copyright © 2025 Idiap Research Institute <contact@idiap.ch>

 SPDX-FileContributor: Philip Abbet <philip.abbet@idiap.ch>

 SPDX-License-Identifier: MPL-2.0
-->


# Assets package for pygafro (Geometric Algebra For RObotics in Python)

Contains mesh and texture files for the robots available in [pygafro](https://github.com/idiap/pygafro/).

**This package is optional and isn't needed if you don't want to display the robots!**
Note that *pygafro* doesn't provide any rendering functions, it only indicates which mesh file
to use for each link.

## Installation using pip

	pip install pygafro-assets

## Background

You can find the accompanying article [here](http://arxiv.org/abs/2212.07237) and more information on our [website](https://geometric-algebra.tobiloew.ch/).

## How to cite

If you use *gafro* in your research, please cite:

	@article{loewGeometricAlgebraOptimal2023,
	  title = {Geometric {{Algebra}} for {{Optimal Control}} with {{Applications}} in {{Manipulation Tasks}}},
	  author = {L\"ow, Tobias and Calinon, Sylvain},
	  date = {2023},
	  journal = {IEEE Transactions on Robotics},
	  doi = {10.1109/TRO.2023.3277282}
	}
